==> zb-exporter-asserts-0.15.0-sources.jar: io/zeebe/exporter/record/Assertions.java <==
package io.zeebe.exporter.record;

/**
 * Entry point for assertions of different data types. Each method in this class is a static factory for the
 * type-specific assertion objects.
 */
@javax.annotation.Generated(value="assertj-assertions-generator")
public class Assertions {

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.RecordAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.RecordAssert assertThat(io.zeebe.exporter.record.Record actual) {
    return new io.zeebe.exporter.record.RecordAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.RecordMetadataAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.RecordMetadataAssert assertThat(io.zeebe.exporter.record.RecordMetadata actual) {
    return new io.zeebe.exporter.record.RecordMetadataAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.RecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.RecordValueAssert assertThat(io.zeebe.exporter.record.RecordValue actual) {
    return new io.zeebe.exporter.record.RecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.RecordValueWithPayloadAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.RecordValueWithPayloadAssert assertThat(io.zeebe.exporter.record.RecordValueWithPayload actual) {
    return new io.zeebe.exporter.record.RecordValueWithPayloadAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.DeploymentRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.DeploymentRecordValueAssert assertThat(io.zeebe.exporter.record.value.DeploymentRecordValue actual) {
    return new io.zeebe.exporter.record.value.DeploymentRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.IncidentRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.IncidentRecordValueAssert assertThat(io.zeebe.exporter.record.value.IncidentRecordValue actual) {
    return new io.zeebe.exporter.record.value.IncidentRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.JobBatchRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.JobBatchRecordValueAssert assertThat(io.zeebe.exporter.record.value.JobBatchRecordValue actual) {
    return new io.zeebe.exporter.record.value.JobBatchRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.JobRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.JobRecordValueAssert assertThat(io.zeebe.exporter.record.value.JobRecordValue actual) {
    return new io.zeebe.exporter.record.value.JobRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.MessageRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.MessageRecordValueAssert assertThat(io.zeebe.exporter.record.value.MessageRecordValue actual) {
    return new io.zeebe.exporter.record.value.MessageRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.MessageStartEventSubscriptionRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.MessageStartEventSubscriptionRecordValueAssert assertThat(io.zeebe.exporter.record.value.MessageStartEventSubscriptionRecordValue actual) {
    return new io.zeebe.exporter.record.value.MessageStartEventSubscriptionRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.MessageSubscriptionRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.MessageSubscriptionRecordValueAssert assertThat(io.zeebe.exporter.record.value.MessageSubscriptionRecordValue actual) {
    return new io.zeebe.exporter.record.value.MessageSubscriptionRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.RaftRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.RaftRecordValueAssert assertThat(io.zeebe.exporter.record.value.RaftRecordValue actual) {
    return new io.zeebe.exporter.record.value.RaftRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.TimerRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.TimerRecordValueAssert assertThat(io.zeebe.exporter.record.value.TimerRecordValue actual) {
    return new io.zeebe.exporter.record.value.TimerRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.VariableRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.VariableRecordValueAssert assertThat(io.zeebe.exporter.record.value.VariableRecordValue actual) {
    return new io.zeebe.exporter.record.value.VariableRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.WorkflowInstanceRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.WorkflowInstanceRecordValueAssert assertThat(io.zeebe.exporter.record.value.WorkflowInstanceRecordValue actual) {
    return new io.zeebe.exporter.record.value.WorkflowInstanceRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.WorkflowInstanceSubscriptionRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.WorkflowInstanceSubscriptionRecordValueAssert assertThat(io.zeebe.exporter.record.value.WorkflowInstanceSubscriptionRecordValue actual) {
    return new io.zeebe.exporter.record.value.WorkflowInstanceSubscriptionRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.deployment.DeployedWorkflowAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.deployment.DeployedWorkflowAssert assertThat(io.zeebe.exporter.record.value.deployment.DeployedWorkflow actual) {
    return new io.zeebe.exporter.record.value.deployment.DeployedWorkflowAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.deployment.DeploymentResourceAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.deployment.DeploymentResourceAssert assertThat(io.zeebe.exporter.record.value.deployment.DeploymentResource actual) {
    return new io.zeebe.exporter.record.value.deployment.DeploymentResourceAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.deployment.ResourceTypeAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.deployment.ResourceTypeAssert assertThat(io.zeebe.exporter.record.value.deployment.ResourceType actual) {
    return new io.zeebe.exporter.record.value.deployment.ResourceTypeAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.job.HeadersAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.job.HeadersAssert assertThat(io.zeebe.exporter.record.value.job.Headers actual) {
    return new io.zeebe.exporter.record.value.job.HeadersAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.raft.RaftMemberAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.raft.RaftMemberAssert assertThat(io.zeebe.exporter.record.value.raft.RaftMember actual) {
    return new io.zeebe.exporter.record.value.raft.RaftMemberAssert(actual);
  }

  /**
   * Creates a new <code>{@link Assertions}</code>.
   */
  protected Assertions() {
    // empty
  }
}

==> zb-exporter-asserts-0.16.3-sources.jar: io/zeebe/exporter/record/Assertions.java <==
package io.zeebe.exporter.record;

/**
 * Entry point for assertions of different data types. Each method in this class is a static factory for the
 * type-specific assertion objects.
 */
@javax.annotation.Generated(value="assertj-assertions-generator")
public class Assertions {

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.RecordAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.RecordAssert assertThat(io.zeebe.exporter.record.Record actual) {
    return new io.zeebe.exporter.record.RecordAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.RecordMetadataAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.RecordMetadataAssert assertThat(io.zeebe.exporter.record.RecordMetadata actual) {
    return new io.zeebe.exporter.record.RecordMetadataAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.RecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.RecordValueAssert assertThat(io.zeebe.exporter.record.RecordValue actual) {
    return new io.zeebe.exporter.record.RecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.RecordValueWithPayloadAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.RecordValueWithPayloadAssert assertThat(io.zeebe.exporter.record.RecordValueWithPayload actual) {
    return new io.zeebe.exporter.record.RecordValueWithPayloadAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.DeploymentRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.DeploymentRecordValueAssert assertThat(io.zeebe.exporter.record.value.DeploymentRecordValue actual) {
    return new io.zeebe.exporter.record.value.DeploymentRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.IncidentRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.IncidentRecordValueAssert assertThat(io.zeebe.exporter.record.value.IncidentRecordValue actual) {
    return new io.zeebe.exporter.record.value.IncidentRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.JobBatchRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.JobBatchRecordValueAssert assertThat(io.zeebe.exporter.record.value.JobBatchRecordValue actual) {
    return new io.zeebe.exporter.record.value.JobBatchRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.JobRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.JobRecordValueAssert assertThat(io.zeebe.exporter.record.value.JobRecordValue actual) {
    return new io.zeebe.exporter.record.value.JobRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.MessageRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.MessageRecordValueAssert assertThat(io.zeebe.exporter.record.value.MessageRecordValue actual) {
    return new io.zeebe.exporter.record.value.MessageRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.MessageStartEventSubscriptionRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.MessageStartEventSubscriptionRecordValueAssert assertThat(io.zeebe.exporter.record.value.MessageStartEventSubscriptionRecordValue actual) {
    return new io.zeebe.exporter.record.value.MessageStartEventSubscriptionRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.MessageSubscriptionRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.MessageSubscriptionRecordValueAssert assertThat(io.zeebe.exporter.record.value.MessageSubscriptionRecordValue actual) {
    return new io.zeebe.exporter.record.value.MessageSubscriptionRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.RaftRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.RaftRecordValueAssert assertThat(io.zeebe.exporter.record.value.RaftRecordValue actual) {
    return new io.zeebe.exporter.record.value.RaftRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.TimerRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.TimerRecordValueAssert assertThat(io.zeebe.exporter.record.value.TimerRecordValue actual) {
    return new io.zeebe.exporter.record.value.TimerRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.VariableDocumentRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.VariableDocumentRecordValueAssert assertThat(io.zeebe.exporter.record.value.VariableDocumentRecordValue actual) {
    return new io.zeebe.exporter.record.value.VariableDocumentRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.VariableRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.VariableRecordValueAssert assertThat(io.zeebe.exporter.record.value.VariableRecordValue actual) {
    return new io.zeebe.exporter.record.value.VariableRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.WorkflowInstanceCreationRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.WorkflowInstanceCreationRecordValueAssert assertThat(io.zeebe.exporter.record.value.WorkflowInstanceCreationRecordValue actual) {
    return new io.zeebe.exporter.record.value.WorkflowInstanceCreationRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.WorkflowInstanceRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.WorkflowInstanceRecordValueAssert assertThat(io.zeebe.exporter.record.value.WorkflowInstanceRecordValue actual) {
    return new io.zeebe.exporter.record.value.WorkflowInstanceRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.WorkflowInstanceSubscriptionRecordValueAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.WorkflowInstanceSubscriptionRecordValueAssert assertThat(io.zeebe.exporter.record.value.WorkflowInstanceSubscriptionRecordValue actual) {
    return new io.zeebe.exporter.record.value.WorkflowInstanceSubscriptionRecordValueAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.deployment.DeployedWorkflowAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.deployment.DeployedWorkflowAssert assertThat(io.zeebe.exporter.record.value.deployment.DeployedWorkflow actual) {
    return new io.zeebe.exporter.record.value.deployment.DeployedWorkflowAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.deployment.DeploymentResourceAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.deployment.DeploymentResourceAssert assertThat(io.zeebe.exporter.record.value.deployment.DeploymentResource actual) {
    return new io.zeebe.exporter.record.value.deployment.DeploymentResourceAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.deployment.ResourceTypeAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.deployment.ResourceTypeAssert assertThat(io.zeebe.exporter.record.value.deployment.ResourceType actual) {
    return new io.zeebe.exporter.record.value.deployment.ResourceTypeAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.job.HeadersAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.job.HeadersAssert assertThat(io.zeebe.exporter.record.value.job.Headers actual) {
    return new io.zeebe.exporter.record.value.job.HeadersAssert(actual);
  }

  /**
   * Creates a new instance of <code>{@link io.zeebe.exporter.record.value.raft.RaftMemberAssert}</code>.
   *
   * @param actual the actual value.
   * @return the created assertion object.
   */
  @org.assertj.core.util.CheckReturnValue
  public static io.zeebe.exporter.record.value.raft.RaftMemberAssert assertThat(io.zeebe.exporter.record.value.raft.RaftMember actual) {
    return new io.zeebe.exporter.record.value.raft.RaftMemberAssert(actual);
  }

  /**
   * Creates a new <code>{@link Assertions}</code>.
   */
  protected Assertions() {
    // empty
  }
}
